==> openshift-client-4.13.0-sources.jar: io/fabric8/openshift/client/dsl/internal/ImageContentSourcePolicyOperationsImpl.java <==

                
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1alpha1.DoneableImageContentSourcePolicy;
import io.fabric8.openshift.api.model.operator.v1alpha1.ImageContentSourcePolicy;
import io.fabric8.openshift.api.model.operator.v1alpha1.ImageContentSourcePolicyList;
import io.fabric8.openshift.api.model.operator.v1alpha1.DoneableImageContentSourcePolicy;

import java.util.Map;
import java.util.TreeMap;


public class ImageContentSourcePolicyOperationsImpl extends OpenShiftOperation<ImageContentSourcePolicy, ImageContentSourcePolicyList, DoneableImageContentSourcePolicy, Resource<ImageContentSourcePolicy, DoneableImageContentSourcePolicy>> {

  public ImageContentSourcePolicyOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ImageContentSourcePolicyOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1alpha1")
    .withPlural("imagecontentsourcepolicies"));
    this.type = ImageContentSourcePolicy.class;
    this.listType = ImageContentSourcePolicyList.class;
    this.doneableType = DoneableImageContentSourcePolicy.class;
  }

  public ImageContentSourcePolicyOperationsImpl newInstance(OperationContext context) {
    return new ImageContentSourcePolicyOperationsImpl(context);
  }
  
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}

==> openshift-client-5.1.1-sources.jar: io/fabric8/openshift/client/dsl/internal/ImageContentSourcePolicyOperationsImpl.java <==

                            
  

package io.fabric8.openshift.client.dsl.internal;

import io.fabric8.kubernetes.api.builder.Visitor;
import io.fabric8.openshift.client.OpenShiftConfig;
import io.fabric8.kubernetes.client.dsl.Resource;
import io.fabric8.kubernetes.client.dsl.base.HasMetadataOperation;
import io.fabric8.kubernetes.client.dsl.NonNamespaceOperation;
import io.fabric8.kubernetes.client.utils.ApiVersionUtil;
import io.fabric8.kubernetes.client.dsl.base.OperationContext;
import io.fabric8.openshift.client.OpenShiftConfig;

import okhttp3.OkHttpClient;

import io.fabric8.openshift.api.model.operator.v1alpha1.ImageContentSourcePolicy;
import io.fabric8.openshift.api.model.operator.v1alpha1.ImageContentSourcePolicyBuilder;
import io.fabric8.openshift.api.model.operator.v1alpha1.ImageContentSourcePolicyList;

import java.util.Map;
import java.util.TreeMap;


public class ImageContentSourcePolicyOperationsImpl extends OpenShiftOperation<ImageContentSourcePolicy, ImageContentSourcePolicyList, Resource<ImageContentSourcePolicy>> {

  public ImageContentSourcePolicyOperationsImpl(OkHttpClient client, OpenShiftConfig config) {
    this(new OperationContext().withOkhttpClient(client).withConfig(config).withPropagationPolicy(DEFAULT_PROPAGATION_POLICY));
  }

  public ImageContentSourcePolicyOperationsImpl(OperationContext context) {
    super(context.withApiGroupName("operator.openshift.io")
    .withApiGroupVersion("v1alpha1")
    .withPlural("imagecontentsourcepolicies"));
    this.type = ImageContentSourcePolicy.class;
    this.listType = ImageContentSourcePolicyList.class;
  }

  public ImageContentSourcePolicyOperationsImpl newInstance(OperationContext context) {
    return new ImageContentSourcePolicyOperationsImpl(context);
  }

  @Override
  public ImageContentSourcePolicy edit(Visitor... visitors) {
    return patch(new ImageContentSourcePolicyBuilder(getMandatory()).accept(visitors).build());
  }
 
  @Override
  public boolean isResourceNamespaced() {
    return false;
  }
}
